4.14. umbra.components.factory.preferencesManager.preferencesManager — Umbra 1.0.9 documentation

# 4.14. umbra.components.factory.preferencesManager.preferencesManager

preferencesManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `PreferencesManager` Component Interface class.

Others:

## 4.14.1. Module Attributes

`umbra.components.factory.preferencesManager.preferencesManager.` `LOGGER`

`umbra.components.factory.preferencesManager.preferencesManager.` `COMPONENT_UI_FILE`

## 4.14.2. Classes

class `umbra.components.factory.preferencesManager.preferencesManager.` `PreferencesManager`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `umbra.components.factory.preferencesManager.preferencesManager` Component Interface class.
  It exposes Application preferences inside a dedicated QDockWidget window.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `dockArea`

    Property for self.__dockArea attribute.

    Returns: | self.__dockArea.
    Return type: | int

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

  `setLoggingFormatter`()

    Sets the logging formatter.